from django.shortcuts import render
from django.contrib.auth.decorators import login_required
from django.db.models import Q

from whoisdb.models import ASNumber, InetNum
from domains.models import Domain
from rrequests.models import Request


@login_required
def profile(request):
	return render(request, "profile/profile.html", {})


@login_required
def dashboard(request):
	mnts = request.user.maintainer_set.all()
	asns = ASNumber.objects.filter(Q(mnt_by__in=mnts) | Q(mnt_lower__in=mnts))
	inetnums = InetNum.objects.filter(Q(mnt_by__in=mnts) | Q(mnt_lower__in=mnts))
	domains = Domain.objects.filter(mnt_by__in=mnts)
	rrequests = Request.objects.filter((Q(provider__in=mnts) | Q(applicant__in=mnts)) & Q(status=Request.STATE_OPEN))

	return render(request, "dncore/dashboard.html", {"asns": asns, "inetnums": inetnums, "domains": domains, 'rrequests': rrequests})


def index(request):
	return render(request, "index.html", {})
